@@ -18,7 +18,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
   Context("based on legacy fluentd forward method", func() {
     BeforeEach(func() {
       lfSpec = &loggingv1alpha1.ForwardingSpec{}
-      generator, err = NewConfigGenerator(true, false)
+      generator, err = NewConfigGenerator(true, false, false)
       Expect(err).To(BeNil())
     })
 
@@ -89,6 +89,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
           path "/var/log/containers/*.log"
           exclude_path ["/var/log/containers/fluentd-*_openshift-logging_*.log", "/var/log/containers/elasticsearch-*_openshift-logging_*.log", "/var/log/containers/kibana-*_openshift-logging_*.log"]
           pos_file "/var/log/es-containers.log.pos"
+          pos_file_compaction_interval 1800
           refresh_interval 5
           rotate_wait 5
           tag kubernetes.*
@@ -116,6 +117,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
           @label @INGRESS
           path "#{ENV['AUDIT_FILE'] || '/var/log/audit/audit.log'}"
           pos_file "#{ENV['AUDIT_POS_FILE'] || '/var/log/audit/audit.log.pos'}"
+          pos_file_compaction_interval 1800
           tag linux-audit.log
           <parse>
             @type viaq_host_audit
@@ -128,6 +130,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
           @label @INGRESS
           path "#{ENV['K8S_AUDIT_FILE'] || '/var/log/kube-apiserver/audit.log'}"
           pos_file "#{ENV['K8S_AUDIT_POS_FILE'] || '/var/log/kube-apiserver/audit.log.pos'}"
+          pos_file_compaction_interval 1800
           tag k8s-audit.log
           <parse>
             @type json
@@ -145,6 +148,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
           @label @INGRESS
           path "#{ENV['OPENSHIFT_AUDIT_FILE'] || '/var/log/openshift-apiserver/audit.log'}"
           pos_file "#{ENV['OPENSHIFT_AUDIT_FILE'] || '/var/log/openshift-apiserver/audit.log.pos'}"
+          pos_file_compaction_interval 1800
           tag openshift-audit.log
           <parse>
             @type json
@@ -299,6 +303,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
 
           <filter **>
             @type viaq_data_model
+            elasticsearch_index_prefix_field 'viaq_index_name'
             default_keep_fields CEE,time,@timestamp,aushape,ci_job,collectd,docker,fedora-ci,file,foreman,geoip,hostname,ipaddr4,ipaddr6,kubernetes,level,message,namespace_name,namespace_uuid,offset,openstack,ovirt,pid,pipeline_metadata,rsyslog,service,systemd,tags,testcase,tlog,viaq_msg_id
             extra_keep_fields "#{ENV['CDM_EXTRA_KEEP_FIELDS'] || ''}"
             keep_empty_fields "#{ENV['CDM_KEEP_EMPTY_FIELDS'] || 'message'}"
@@ -342,17 +347,20 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             <elasticsearch_index_name>
               enabled "#{ENV['ENABLE_ES_INDEX_NAME'] || 'true'}"
               tag "journal.system** system.var.log** **_default_** **_kube-*_** **_openshift-*_** **_openshift_**"
-              name_type operations_full
+              name_type static
+              static_index_name infra-write
             </elasticsearch_index_name>
             <elasticsearch_index_name>
               enabled "#{ENV['ENABLE_ES_INDEX_NAME'] || 'true'}"
               tag "linux-audit.log** k8s-audit.log** openshift-audit.log**"
-              name_type audit_full
+              name_type static
+              static_index_name audit-write
             </elasticsearch_index_name>
             <elasticsearch_index_name>
               enabled "#{ENV['ENABLE_ES_INDEX_NAME'] || 'true'}"
               tag "**"
-              name_type project_full
+              name_type static
+              static_index_name app-write
             </elasticsearch_index_name>
           </filter>
 
@@ -363,6 +371,16 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             alt_tags "#{ENV['GENID_ALT_TAG'] || 'kubernetes.var.log.containers.logging-eventrouter-*.** kubernetes.var.log.containers.eventrouter-*.** kubernetes.var.log.containers.cluster-logging-eventrouter-*.** kubernetes.journal.container._default_.kubernetes-event'}"
           </filter>
 
+          #flatten labels to prevent field explosion in ES
+          <filter ** >
+            @type record_transformer
+            enable_ruby true
+            <record>
+              kubernetes ${!record['kubernetes'].nil? ? record['kubernetes'].merge({"flat_labels": (record['kubernetes']['labels']||{}).map{|k,v| "#{k}=#{v}"}}) : {} }
+            </record>
+            remove_keys $.kubernetes.labels
+          </filter>
+
           # Relabel specific source tags to specific intermediary labels for copy processing
 
           <match **_default_** **_kube-*_** **_openshift-*_** **_openshift_** journal.** system.var.log**>
@@ -444,7 +462,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
   Context("based on legacy syslog method", func() {
     BeforeEach(func() {
       lfSpec = &loggingv1alpha1.ForwardingSpec{}
-      generator, err = NewConfigGenerator(false, true)
+      generator, err = NewConfigGenerator(false, true, false)
       Expect(err).To(BeNil())
     })
 
@@ -515,6 +533,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
           path "/var/log/containers/*.log"
           exclude_path ["/var/log/containers/fluentd-*_openshift-logging_*.log", "/var/log/containers/elasticsearch-*_openshift-logging_*.log", "/var/log/containers/kibana-*_openshift-logging_*.log"]
           pos_file "/var/log/es-containers.log.pos"
+          pos_file_compaction_interval 1800
           refresh_interval 5
           rotate_wait 5
           tag kubernetes.*
@@ -542,6 +561,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
           @label @INGRESS
           path "#{ENV['AUDIT_FILE'] || '/var/log/audit/audit.log'}"
           pos_file "#{ENV['AUDIT_POS_FILE'] || '/var/log/audit/audit.log.pos'}"
+          pos_file_compaction_interval 1800
           tag linux-audit.log
           <parse>
             @type viaq_host_audit
@@ -554,6 +574,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
           @label @INGRESS
           path "#{ENV['K8S_AUDIT_FILE'] || '/var/log/kube-apiserver/audit.log'}"
           pos_file "#{ENV['K8S_AUDIT_POS_FILE'] || '/var/log/kube-apiserver/audit.log.pos'}"
+          pos_file_compaction_interval 1800
           tag k8s-audit.log
           <parse>
             @type json
@@ -571,6 +592,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
           @label @INGRESS
           path "#{ENV['OPENSHIFT_AUDIT_FILE'] || '/var/log/openshift-apiserver/audit.log'}"
           pos_file "#{ENV['OPENSHIFT_AUDIT_FILE'] || '/var/log/openshift-apiserver/audit.log.pos'}"
+          pos_file_compaction_interval 1800
           tag openshift-audit.log
           <parse>
             @type json
@@ -725,6 +747,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
 
           <filter **>
             @type viaq_data_model
+            elasticsearch_index_prefix_field 'viaq_index_name'
             default_keep_fields CEE,time,@timestamp,aushape,ci_job,collectd,docker,fedora-ci,file,foreman,geoip,hostname,ipaddr4,ipaddr6,kubernetes,level,message,namespace_name,namespace_uuid,offset,openstack,ovirt,pid,pipeline_metadata,rsyslog,service,systemd,tags,testcase,tlog,viaq_msg_id
             extra_keep_fields "#{ENV['CDM_EXTRA_KEEP_FIELDS'] || ''}"
             keep_empty_fields "#{ENV['CDM_KEEP_EMPTY_FIELDS'] || 'message'}"
@@ -768,17 +791,20 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             <elasticsearch_index_name>
               enabled "#{ENV['ENABLE_ES_INDEX_NAME'] || 'true'}"
               tag "journal.system** system.var.log** **_default_** **_kube-*_** **_openshift-*_** **_openshift_**"
-              name_type operations_full
+              name_type static
+              static_index_name infra-write
             </elasticsearch_index_name>
             <elasticsearch_index_name>
               enabled "#{ENV['ENABLE_ES_INDEX_NAME'] || 'true'}"
               tag "linux-audit.log** k8s-audit.log** openshift-audit.log**"
-              name_type audit_full
+              name_type static
+              static_index_name audit-write
             </elasticsearch_index_name>
             <elasticsearch_index_name>
               enabled "#{ENV['ENABLE_ES_INDEX_NAME'] || 'true'}"
               tag "**"
-              name_type project_full
+              name_type static
+              static_index_name app-write
             </elasticsearch_index_name>
           </filter>
 
@@ -789,6 +815,16 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             alt_tags "#{ENV['GENID_ALT_TAG'] || 'kubernetes.var.log.containers.logging-eventrouter-*.** kubernetes.var.log.containers.eventrouter-*.** kubernetes.var.log.containers.cluster-logging-eventrouter-*.** kubernetes.journal.container._default_.kubernetes-event'}"
           </filter>
 
+          #flatten labels to prevent field explosion in ES
+          <filter ** >
+            @type record_transformer
+            enable_ruby true
+            <record>
+              kubernetes ${!record['kubernetes'].nil? ? record['kubernetes'].merge({"flat_labels": (record['kubernetes']['labels']||{}).map{|k,v| "#{k}=#{v}"}}) : {} }
+            </record>
+            remove_keys $.kubernetes.labels
+          </filter>
+
           # Relabel specific source tags to specific intermediary labels for copy processing
 
           <match **_default_** **_kube-*_** **_openshift-*_** **_openshift_** journal.** system.var.log**>
@@ -871,7 +907,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
   Context("based on legacy syslog and fluentd forward method", func() {
     BeforeEach(func() {
       lfSpec = &loggingv1alpha1.ForwardingSpec{}
-      generator, err = NewConfigGenerator(true, true)
+      generator, err = NewConfigGenerator(true, true, false)
       Expect(err).To(BeNil())
     })
 
@@ -942,6 +978,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
           path "/var/log/containers/*.log"
           exclude_path ["/var/log/containers/fluentd-*_openshift-logging_*.log", "/var/log/containers/elasticsearch-*_openshift-logging_*.log", "/var/log/containers/kibana-*_openshift-logging_*.log"]
           pos_file "/var/log/es-containers.log.pos"
+          pos_file_compaction_interval 1800
           refresh_interval 5
           rotate_wait 5
           tag kubernetes.*
@@ -969,6 +1006,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
           @label @INGRESS
           path "#{ENV['AUDIT_FILE'] || '/var/log/audit/audit.log'}"
           pos_file "#{ENV['AUDIT_POS_FILE'] || '/var/log/audit/audit.log.pos'}"
+          pos_file_compaction_interval 1800
           tag linux-audit.log
           <parse>
             @type viaq_host_audit
@@ -981,6 +1019,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
           @label @INGRESS
           path "#{ENV['K8S_AUDIT_FILE'] || '/var/log/kube-apiserver/audit.log'}"
           pos_file "#{ENV['K8S_AUDIT_POS_FILE'] || '/var/log/kube-apiserver/audit.log.pos'}"
+          pos_file_compaction_interval 1800
           tag k8s-audit.log
           <parse>
             @type json
@@ -998,6 +1037,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
           @label @INGRESS
           path "#{ENV['OPENSHIFT_AUDIT_FILE'] || '/var/log/openshift-apiserver/audit.log'}"
           pos_file "#{ENV['OPENSHIFT_AUDIT_FILE'] || '/var/log/openshift-apiserver/audit.log.pos'}"
+          pos_file_compaction_interval 1800
           tag openshift-audit.log
           <parse>
             @type json
@@ -1152,6 +1192,7 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
 
           <filter **>
             @type viaq_data_model
+            elasticsearch_index_prefix_field 'viaq_index_name'
             default_keep_fields CEE,time,@timestamp,aushape,ci_job,collectd,docker,fedora-ci,file,foreman,geoip,hostname,ipaddr4,ipaddr6,kubernetes,level,message,namespace_name,namespace_uuid,offset,openstack,ovirt,pid,pipeline_metadata,rsyslog,service,systemd,tags,testcase,tlog,viaq_msg_id
             extra_keep_fields "#{ENV['CDM_EXTRA_KEEP_FIELDS'] || ''}"
             keep_empty_fields "#{ENV['CDM_KEEP_EMPTY_FIELDS'] || 'message'}"
@@ -1195,17 +1236,20 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             <elasticsearch_index_name>
               enabled "#{ENV['ENABLE_ES_INDEX_NAME'] || 'true'}"
               tag "journal.system** system.var.log** **_default_** **_kube-*_** **_openshift-*_** **_openshift_**"
-              name_type operations_full
+              name_type static
+              static_index_name infra-write
             </elasticsearch_index_name>
             <elasticsearch_index_name>
               enabled "#{ENV['ENABLE_ES_INDEX_NAME'] || 'true'}"
               tag "linux-audit.log** k8s-audit.log** openshift-audit.log**"
-              name_type audit_full
+              name_type static
+              static_index_name audit-write
             </elasticsearch_index_name>
             <elasticsearch_index_name>
               enabled "#{ENV['ENABLE_ES_INDEX_NAME'] || 'true'}"
               tag "**"
-              name_type project_full
+              name_type static
+              static_index_name app-write
             </elasticsearch_index_name>
           </filter>
 
@@ -1216,6 +1260,16 @@ var _ = Describe("Generating fluentd legacy output store config blocks", func()
             alt_tags "#{ENV['GENID_ALT_TAG'] || 'kubernetes.var.log.containers.logging-eventrouter-*.** kubernetes.var.log.containers.eventrouter-*.** kubernetes.var.log.containers.cluster-logging-eventrouter-*.** kubernetes.journal.container._default_.kubernetes-event'}"
           </filter>
 
+          #flatten labels to prevent field explosion in ES
+          <filter ** >
+            @type record_transformer
+            enable_ruby true
+            <record>
+              kubernetes ${!record['kubernetes'].nil? ? record['kubernetes'].merge({"flat_labels": (record['kubernetes']['labels']||{}).map{|k,v| "#{k}=#{v}"}}) : {} }
+            </record>
+            remove_keys $.kubernetes.labels
+          </filter>
+
           # Relabel specific source tags to specific intermediary labels for copy processing
 
           <match **_default_** **_kube-*_** **_openshift-*_** **_openshift_** journal.** system.var.log**>
