@@ -25,9 +25,10 @@ import (
 )
 
 const (
-	fluentdAlertsFile = "fluentd/fluentd_prometheus_alerts.yaml"
-	fluentdName       = "fluentd"
-	syslogName        = "syslog"
+	fluentdAlertsFile        = "fluentd/fluentd_prometheus_alerts.yaml"
+	fluentdName              = "fluentd"
+	syslogName               = "syslog"
+	fluentdRequiredESVersion = "6"
 )
 
 func (clusterRequest *ClusterLoggingRequest) removeFluentd() (err error) {
@@ -192,6 +193,18 @@ func (clusterRequest *ClusterLoggingRequest) includeLegacySyslogConfig() bool {
 	return found
 }
 
+// useOldPlugin checks if old plugin (docebo/fluent-plugin-remote-syslog) is to be used for sending syslog or new plugin (dlackty/fluent-plugin-remote_syslog) is to be used
+func (clusterRequest *ClusterLoggingRequest) useOldRemoteSyslogPlugin() bool {
+	if clusterRequest.ForwardingRequest == nil {
+		return false
+	}
+
+	if enabled, found := clusterRequest.ForwardingRequest.Annotations[UseOldRemoteSyslogPlugin]; found && enabled == "enabled" {
+		return true
+	}
+	return false
+}
+
 func (clusterRequest *ClusterLoggingRequest) createOrUpdateFluentdConfigMap(fluentConf string) error {
 	logrus.Debug("createOrUpdateFluentdConfigMap...")
 	fluentdConfigMap := NewConfigMap(
@@ -255,7 +268,7 @@ func newFluentdPodSpec(cluster *logging.ClusterLogging, elasticsearchAppName str
 	if cluster.Spec.Collection != nil {
 		collectionSpec = *cluster.Spec.Collection
 	}
-	var resources = collectionSpec.Logs.FluentdSpec.Resources
+	resources := collectionSpec.Logs.FluentdSpec.Resources
 	if resources == nil {
 		resources = &v1.ResourceRequirements{
 			Limits: v1.ResourceList{v1.ResourceMemory: defaultFluentdMemory},
@@ -268,7 +281,7 @@ func newFluentdPodSpec(cluster *logging.ClusterLogging, elasticsearchAppName str
 	fluentdContainer := NewContainer("fluentd", "fluentd", v1.PullIfNotPresent, *resources)
 
 	fluentdContainer.Ports = []v1.ContainerPort{
-		v1.ContainerPort{
+		{
 			Name:          metricsPortName,
 			ContainerPort: metricsPort,
 			Protocol:      v1.ProtocolTCP,
@@ -337,12 +350,12 @@ func newFluentdPodSpec(cluster *logging.ClusterLogging, elasticsearchAppName str
 	tolerations := utils.AppendTolerations(
 		collectionSpec.Logs.FluentdSpec.Tolerations,
 		[]v1.Toleration{
-			v1.Toleration{
+			{
 				Key:      "node-role.kubernetes.io/master",
 				Operator: v1.TolerationOpExists,
 				Effect:   v1.TaintEffectNoSchedule,
 			},
-			v1.Toleration{
+			{
 				Key:      "node.kubernetes.io/disk-pressure",
 				Operator: v1.TolerationOpExists,
 				Effect:   v1.TaintEffectNoSchedule,
@@ -403,9 +416,44 @@ func newFluentdPodSpec(cluster *logging.ClusterLogging, elasticsearchAppName str
 	// Shorten the termination grace period from the default 30 sec to 10 sec.
 	fluentdPodSpec.TerminationGracePeriodSeconds = utils.GetInt64(10)
 
+	if !pipelineSpec.DisableDefaultForwarding && cluster.Spec.LogStore != nil {
+		fluentdPodSpec.InitContainers = []v1.Container{
+			newFluentdInitContainer(cluster),
+		}
+	} else {
+		fluentdPodSpec.InitContainers = []v1.Container{}
+	}
+
 	return fluentdPodSpec
 }
 
+func newFluentdInitContainer(cluster *logging.ClusterLogging) v1.Container {
+	collectionSpec := logging.CollectionSpec{}
+	resources := collectionSpec.Logs.FluentdSpec.Resources
+	if resources == nil {
+		resources = &v1.ResourceRequirements{
+			Limits: v1.ResourceList{v1.ResourceMemory: defaultFluentdMemory},
+			Requests: v1.ResourceList{
+				v1.ResourceMemory: defaultFluentdMemory,
+				v1.ResourceCPU:    defaultFluentdCpuRequest,
+			},
+		}
+	}
+	initContainer := NewContainer("fluentd-init", "fluentd", v1.PullIfNotPresent, *resources)
+
+	initContainer.VolumeMounts = []v1.VolumeMount{
+		{Name: "certs", ReadOnly: true, MountPath: "/etc/fluent/keys"},
+	}
+
+	initContainer.Command = []string{
+		"./wait_for_es_version.sh",
+		fluentdRequiredESVersion,
+		fmt.Sprintf("https://%s.%s.svc:9200", elasticsearchResourceName, cluster.Namespace),
+	}
+
+	return initContainer
+}
+
 func (clusterRequest *ClusterLoggingRequest) createOrUpdateFluentdDaemonset(pipelineConfHash string, proxyConfig *configv1.Proxy) (err error) {
 
 	cluster := clusterRequest.cluster
