@@ -79,46 +79,12 @@ func (clusterRequest *ClusterLoggingRequest) getFluentdCollectorStatus() (loggin
 	return fluentdStatus, nil
 }
 
-func (clusterRequest *ClusterLoggingRequest) getKibanaStatus() ([]logging.KibanaStatus, error) {
-
-	status := []logging.KibanaStatus{}
-	selector := map[string]string{
-		"logging-infra": "kibana",
-	}
-
-	kibanaDeploymentList, err := clusterRequest.GetDeploymentList(selector)
+func (clusterRequest *ClusterLoggingRequest) getKibanaStatus() ([]elasticsearch.KibanaStatus, error) {
+	cr, err := clusterRequest.getKibanaCR()
 	if err != nil {
-		return status, err
+		return nil, err
 	}
-
-	for _, deployment := range kibanaDeploymentList.Items {
-
-		selector["component"] = deployment.Name
-
-		kibanaStatus := logging.KibanaStatus{
-			Deployment: deployment.Name,
-			Replicas:   *deployment.Spec.Replicas,
-		}
-
-		replicaSetList, _ := clusterRequest.GetReplicaSetList(selector)
-		replicaNames := []string{}
-		for _, replicaSet := range replicaSetList.Items {
-			replicaNames = append(replicaNames, replicaSet.Name)
-		}
-		kibanaStatus.ReplicaSets = replicaNames
-
-		podList, _ := clusterRequest.GetPodList(selector)
-		kibanaStatus.Pods = podStateMap(podList.Items)
-
-		kibanaStatus.Conditions, err = clusterRequest.getPodConditions("kibana")
-		if err != nil {
-			return status, fmt.Errorf("unable to get pod conditions. E: %s", err.Error())
-		}
-
-		status = append(status, kibanaStatus)
-	}
-
-	return status, nil
+	return cr.Status, nil
 }
 
 func (clusterRequest *ClusterLoggingRequest) getElasticsearchStatus() ([]logging.ElasticsearchStatus, error) {
@@ -141,16 +107,15 @@ func (clusterRequest *ClusterLoggingRequest) getElasticsearchStatus() ([]logging
 
 	if len(esList.Items) != 0 {
 		for _, cluster := range esList.Items {
-
-			nodeConditions := make(map[string][]elasticsearch.ClusterCondition)
+			nodeConditions := make(map[string]logging.ElasticsearchClusterConditions)
 
 			nodeStatus := logging.ElasticsearchStatus{
 				ClusterName:            cluster.Name,
-				NodeCount:              cluster.Spec.Nodes[0].NodeCount,
+				NodeCount:              cluster.Status.Cluster.NumNodes,
 				ClusterHealth:          cluster.Status.ClusterHealth,
 				Cluster:                cluster.Status.Cluster,
 				Pods:                   getPodMap(cluster.Status),
-				ClusterConditions:      cluster.Status.Conditions,
+				ClusterConditions:      logging.ElasticsearchClusterConditions(cluster.Status.Conditions),
 				ShardAllocationEnabled: cluster.Status.ShardAllocationEnabled,
 			}
 
@@ -166,7 +131,7 @@ func (clusterRequest *ClusterLoggingRequest) getElasticsearchStatus() ([]logging
 				}
 
 				if node.Conditions != nil {
-					nodeConditions[nodeName] = node.Conditions
+					nodeConditions[nodeName] = logging.ElasticsearchClusterConditions(node.Conditions)
 				} else {
 					nodeConditions[nodeName] = []elasticsearch.ClusterCondition{}
 				}
@@ -235,10 +200,10 @@ func isPodReady(pod v1.Pod) bool {
 	return true
 }
 
-func (clusterRequest *ClusterLoggingRequest) getPodConditions(component string) (map[string][]logging.ClusterCondition, error) {
+func (clusterRequest *ClusterLoggingRequest) getPodConditions(component string) (map[string]logging.ClusterConditions, error) {
 	// Get all pods based on status.Nodes[] and check their conditions
 	// get pod with label 'node-name=node.getName()'
-	podConditions := make(map[string][]logging.ClusterCondition)
+	podConditions := make(map[string]logging.ClusterConditions)
 
 	nodePodList := &core.PodList{
 		TypeMeta: metav1.TypeMeta{
@@ -291,7 +256,7 @@ func (clusterRequest *ClusterLoggingRequest) getPodConditions(component string)
 						Status:             v1.ConditionTrue,
 						Reason:             containerStatus.State.Terminated.Reason,
 						Message:            containerStatus.State.Terminated.Message,
-						LastTransitionTime: metav1.Now(),
+						LastTransitionTime: containerStatus.State.Terminated.FinishedAt,
 					})
 				}
 			}
